@@ -7,8 +7,10 @@ import time
 from isodate import duration_isoformat
 
 from gateways.apis.api_route_base import ApiRoot
+from gateways.bitbucket_gateway import BitbucketGateway
 from gateways.common.cs18_api_classes import BlueprintRepositoryDetails, AccessLink, \
-    AddBlueprintUsingTokenRepositoryRequest, AddBlueprintGithubRepositoryRequest, AddBlueprintBitbucketRepositoryRequest
+    AddBlueprintUsingTokenRepositoryRequest, AddBlueprintGithubRepositoryRequest, \
+    AddBlueprintBitbucketRepositoryRequest, BitbucketBlueprintRepositoryDetails
 from gateways.common.cs18_api_converters import Converters
 from gateways.common.cs18_api_errors import UnauthorizedException, SandboxNotFound, \
     SandboxEndingFailed
@@ -26,7 +28,8 @@ from gateways.common.cs18_api_responses import (AccountStatusResponse, Blueprint
                                                 UserInvitationResponse, UserPermittedToSpaceResponse,
                                                 UserForAllUsersResponse, CloudAccountInSpaceResponse, RegionResponse,
                                                 VerifyCloudProviderResponse, AccountRepositoryResponse,
-                                                BlueprintValidationResponse)
+                                                BlueprintValidationResponse, AccountRepositoryDetailsResponse,
+                                                DirectAwsSshResponse, DirectAzureSshResponse, DirectRdpResponse)
 from gateways.n_session import NSession
 from gateways.the_gateway import TheGateway
 from gateways.utils import GatewayUtils, Utils
@@ -185,6 +188,14 @@ class Colony:
         resp = self.session.post(url=method_url, json=request)
         GatewayUtils.handle_response(response=resp, return_codes=[200])
 
+    def register_gcp_stub_account(self, name: str):
+        method_url = self._api_root.settings.gcp_stub_cloud_accounts()
+        request = {
+            "name": name
+        }
+        resp = self.session.post(url=method_url, json=request)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+
     # todo old function -> tomer delete this in phase 2
     def add_azure_aks(self, name: str, cloud_account_name: str, kube_config: str):
         """ Register AKS"""
@@ -638,21 +649,51 @@ class Colony:
         repositories_json = json.loads(response.text)
         return [Converters.create_account_repository_response(repository) for repository in repositories_json]
 
+    def get_account_blueprint_repository(self, repository_name: str) -> AccountRepositoryResponse:
+        method_url = self._api_root.settings.repository(repository_name)
+        response = self.session.get(url=method_url)
+        GatewayUtils.handle_response(response=response, return_codes=[200])
+
+        repository_json = json.loads(response.text)
+        return Converters.create_account_repository_response(repository_json)
+
+    def get_account_blueprint_repository_details(self, repository_name: str) -> AccountRepositoryDetailsResponse:
+        method_url = self._api_root.settings.repository_details(repository_name)
+        response = self.session.get(url=method_url)
+        GatewayUtils.handle_response(response=response, return_codes=[200])
+
+        repository_details_json = json.loads(response.text)
+        return Converters.create_account_repository_details_response(repository_details_json)
+
     def add_repository_to_space(
             self,
             repository_details: BlueprintRepositoryDetails,
             deployment_type: str = None,
             wait_for_cache_refresh: bool = False,
     ):
-        print(f'repository_url: {repository_details.repository_url} access_token: {repository_details.access_token}')
-        method_url = self._api_root.spaces.space_repositories(space_name=self.space)
-        request = {
-            "repository_url": repository_details.repository_url,
-            "access_token": repository_details.access_token,
-            "repository_type": repository_details.repository_type,
-            "branch": repository_details.branch,
-            "type": deployment_type
-        }
+        if isinstance(repository_details, BitbucketBlueprintRepositoryDetails):
+            repository_details.code = self.get_auth_code_from_bitbucket(repository_details)
+            method_url = self._api_root.spaces.space_repositories(space_name=self.space, repository_type="bitbucket")
+            request = {
+                "repository_url": repository_details.repository_url,
+                "code": repository_details.code,
+                "repository_type": repository_details.repository_type,
+                "branch": repository_details.branch,
+                "type": deployment_type,
+                "redirection_url": repository_details.redirect_url
+            }
+        else:
+            print(
+                f'repository_url: {repository_details.repository_url} access_token: {repository_details.access_token}')
+            method_url = self._api_root.spaces.space_repositories(space_name=self.space)
+            request = {
+                "repository_url": repository_details.repository_url,
+                "access_token": repository_details.access_token,
+                "repository_type": repository_details.repository_type,
+                "branch": repository_details.branch,
+                "type": deployment_type
+            }
+
         resp = self.session.post(url=method_url, json=request)
         GatewayUtils.handle_response(response=resp, return_codes=[200])
 
@@ -1018,6 +1059,110 @@ class Colony:
         verify_json = json.loads(res.text)
         return Converters.create_verify_response(verify_json)
 
+    @staticmethod
+    def get_auth_code_from_bitbucket(repository_details):
+        with BitbucketGateway(
+                username=repository_details.username,
+                password=repository_details.password,
+                client_email=repository_details.client_email,
+                client_id=repository_details.client_id,
+                redirect_url=repository_details.redirect_url) as bitbucket:
+            return bitbucket.get_consumer_app_temporary_code()
+
+    def add_sandbox_repository_to_space(
+            self,
+            space_name: str,
+            account_repository_name: str,
+            branch: str
+    ):
+        request = {
+            "name": account_repository_name,
+            "branch": branch
+        }
+
+        method_url = self._api_root.spaces.space_sandbox_repository(space_name)
+
+        resp = self.session.post(url=method_url, json=request)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+
+    def add_production_repository_to_space(
+            self,
+            space_name: str,
+            account_repository_name: str,
+            branch: str
+    ):
+        request = {
+            "name": account_repository_name,
+            "branch": branch
+        }
+
+        method_url = self._api_root.spaces.space_production_repository(space_name)
+
+        resp = self.session.post(url=method_url, json=request)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+
+    def get_space_sandbox_repository(self, space_name: str):
+        method_url = self._api_root.spaces.space_sandbox_repository(space_name)
+        response = self.session.get(url=method_url)
+        GatewayUtils.handle_response(response=response, return_codes=[200, 204])
+        if not response.text:
+            return None
+        response_json = json.loads(response.text)
+        return Converters.create_space_repository_response(response_json)
+
+    def get_space_production_repository(self, space_name: str):
+        method_url = self._api_root.spaces.space_production_repository(space_name)
+        response = self.session.get(url=method_url)
+        GatewayUtils.handle_response(response=response, return_codes=[200, 204])
+        if not response.text:
+            return None
+        response_json = json.loads(response.text)
+        return Converters.create_space_repository_response(response_json)
+
+    def delete_sandbox_repository_from_space(self, space_name: str):
+        method_url = self._api_root.spaces.space_sandbox_repository(space_name)
+        response = self.session.delete(url=method_url)
+        GatewayUtils.handle_response(response=response, return_codes=[200])
+
+    def delete_production_repository_from_space(self, space_name: str):
+        method_url = self._api_root.spaces.space_production_repository(space_name)
+        response = self.session.delete(url=method_url)
+        GatewayUtils.handle_response(response=response, return_codes=[200])
+
+    def get_debugging_pem_file_content(self, space_name: str, sandbox_id: str, instance_id: str) -> str:
+        method_url = self._api_root.debugging.get_aws_pem_file(space_name, sandbox_id, instance_id)
+        response = self.session.get(url=method_url)
+        GatewayUtils.handle_response(response=response, return_codes=[200])
+        return response.text
+
+    def get_direct_aws_ssh_connect(self, space_name: str, sandbox_id: str, instance_id: str) -> DirectAwsSshResponse:
+        method_url = self._api_root.debugging.get_direct_aws_ssh_connect(space_name, sandbox_id, instance_id)
+        response = self.session.get(url=method_url)
+        GatewayUtils.handle_response(response=response, return_codes=[200])
+        response_json = json.loads(response.text)
+        return Converters.create_direct_aws_ssh_response(response_json)
+
+    def get_direct_azure_ssh_connect(self, space_name: str, sandbox_id: str, instance_id: str) \
+            -> DirectAzureSshResponse:
+        method_url = self._api_root.debugging.get_direct_azure_ssh_connect(space_name, sandbox_id, instance_id)
+        response = self.session.get(url=method_url)
+        GatewayUtils.handle_response(response=response, return_codes=[200])
+        response_json = json.loads(response.text)
+        return Converters.create_direct_azure_ssh_response(response_json)
+
+    def get_debugging_rdp_file_content(self, space_name: str, sandbox_id: str, instance_id: str) -> str:
+        method_url = self._api_root.debugging.get_direct_rpd_file(space_name, sandbox_id, instance_id)
+        response = self.session.get(url=method_url)
+        GatewayUtils.handle_response(response=response, return_codes=[200])
+        return response.text
+
+    def get_direct_rdp_connect(self, space_name: str, sandbox_id: str, instance_id: str) -> DirectRdpResponse:
+        method_url = self._api_root.debugging.get_direct_rpd_connect(space_name, sandbox_id, instance_id)
+        response = self.session.get(url=method_url)
+        GatewayUtils.handle_response(response=response, return_codes=[200])
+        response_json = json.loads(response.text)
+        return Converters.create_direct_rdp_response(response_json)
+
 
 class SandboxesHandler:
     def __init__(self):
