@@ -43,6 +43,18 @@ class BlueprintRepositoryDetails:
         self.branch = branch
 
 
+class BitbucketBlueprintRepositoryDetails(BlueprintRepositoryDetails):
+    def __init__(self, username: str, password: str, client_email: str, client_id: str, redirect_url: str,
+                 repository_url: str, repository_type: str, branch: str = None):
+        self.username = username
+        self.password = password
+        self.client_email = client_email
+        self.client_id = client_id
+        self.redirect_url = redirect_url
+        access_token = ''
+        super(BitbucketBlueprintRepositoryDetails, self).__init__(repository_url, access_token, repository_type, branch)
+
+
 class AddAccountBlueprintRepositoryRequest(abc.ABC):
     def __init__(self, name: str, repository_url: str, allow_sharing: bool,
                  open_access: bool):
