@@ -329,6 +329,7 @@ class ApplicationResponse(ApplicationResponseBase):
             image_name: str,
             icon: str,
             cloud: CloudResponse = None,
+            direct_access_protocols: List[str] = None
     ):
         super().__init__(name=name, status=status, cloud=cloud)
         self.image_name = image_name
@@ -340,6 +341,7 @@ class ApplicationResponse(ApplicationResponseBase):
         self.shortcuts = shortcuts
         self.instances = instances
         self.icon = icon
+        self.direct_access_protocols = direct_access_protocols if direct_access_protocols else []
 
 
 class SandboxOwnerResponse:
@@ -386,7 +388,8 @@ class SandboxResponseBase:
                  scheduled_end_time: datetime,
                  end_time: datetime,
                  debugging_service: str,
-                 source: BlueprintSourceResponse):
+                 source: BlueprintSourceResponse,
+                 direct_access: str):
         self.source = source
         self.sandbox_status = sandbox_status
         self.create_time = create_time
@@ -402,6 +405,7 @@ class SandboxResponseBase:
         self.scheduled_end_time = scheduled_end_time
         self.end_time = end_time
         self.debugging_service = debugging_service
+        self.direct_access = direct_access
 
 
 class InputResponse:
@@ -444,7 +448,8 @@ class SandboxResponse(SandboxResponseBase):
                  end_time: datetime,
                  debugging_service: str,
                  launching_progress: LaunchingProgress,
-                 source: BlueprintSourceResponse):
+                 source: BlueprintSourceResponse,
+                 direct_access: str):
         super().__init__(sandbox_status,
                          create_time,
                          start_time,
@@ -459,7 +464,8 @@ class SandboxResponse(SandboxResponseBase):
                          scheduled_end_time,
                          end_time,
                          debugging_service,
-                         source)
+                         source,
+                         direct_access)
         self.artifacts = artifacts
         self.inputs = inputs
         self.applications = applications
@@ -486,7 +492,8 @@ class SandboxResponseLean(SandboxResponseBase):
                  scheduled_end_time: datetime,
                  end_time: datetime,
                  debugging_service: str,
-                 source: BlueprintSourceResponse):
+                 source: BlueprintSourceResponse,
+                 direct_access: str):
         super().__init__(sandbox_status,
                          create_time,
                          start_time,
@@ -501,7 +508,8 @@ class SandboxResponseLean(SandboxResponseBase):
                          scheduled_end_time,
                          end_time,
                          debugging_service,
-                         source)
+                         source,
+                         direct_access)
         self.end_time = end_time
         self.applications = applications
         self.name = name
@@ -521,7 +529,8 @@ class ProductionResponseLean:
             create_time: datetime,
             deployment_start_time: datetime,
             blue_applications: List[ApplicationResponseLean],
-            blue_services: List[ServiceResponse]):
+            blue_services: List[ServiceResponse],
+            direct_access: str):
         self.production_id = production_id
         self.name = name
         self.blueprint_description = blueprint_description
@@ -533,6 +542,7 @@ class ProductionResponseLean:
         self.deployment_start_time = deployment_start_time
         self.blue_applications = blue_applications
         self.blue_services = blue_services
+        self.direct_access = direct_access
 
 
 class ProductionResponse(metaclass=abc.ABCMeta):
@@ -558,7 +568,8 @@ class ProductionResponse(metaclass=abc.ABCMeta):
             errors: List[SandboxError],
             links: List[HyperlinkResponse],
             debugging_service: str,
-            launching_progress: LaunchingProgress):
+            launching_progress: LaunchingProgress,
+            direct_access: str):
         self.production_id = production_id
         self.sandbox_id = sandbox_id
         self.name = name
@@ -580,6 +591,7 @@ class ProductionResponse(metaclass=abc.ABCMeta):
         self.services = services
         self.debugging_service = debugging_service
         self.launching_progress = launching_progress
+        self.direct_access = direct_access
 
 
 class ProductionBlueResponse(ProductionResponse):
@@ -605,7 +617,8 @@ class ProductionBlueResponse(ProductionResponse):
                  links: List[HyperlinkResponse],
                  has_green: bool,
                  debugging_service: str,
-                 launching_progress: LaunchingProgress):
+                 launching_progress: LaunchingProgress,
+                 direct_access: str):
         super().__init__(
             production_id=production_id,
             sandbox_id=sandbox_id,
@@ -627,7 +640,8 @@ class ProductionBlueResponse(ProductionResponse):
             errors=errors,
             links=links,
             debugging_service=debugging_service,
-            launching_progress=launching_progress)
+            launching_progress=launching_progress,
+            direct_access=direct_access)
         self.has_green = has_green
 
 
@@ -654,7 +668,8 @@ class ProductionGreenResponse(ProductionResponse):
                  links: List[HyperlinkResponse],
                  exposure: int,
                  debugging_service: str,
-                 launching_progress: LaunchingProgress):
+                 launching_progress: LaunchingProgress,
+                 direct_access: str):
         super().__init__(
             production_id=production_id,
             sandbox_id=sandbox_id,
@@ -676,7 +691,8 @@ class ProductionGreenResponse(ProductionResponse):
             errors=errors,
             links=links,
             debugging_service=debugging_service,
-            launching_progress=launching_progress)
+            launching_progress=launching_progress,
+            direct_access=direct_access)
         self.exposure = exposure
 
 
@@ -710,12 +726,14 @@ class ComputeServiceBaseResponse:
                  service_type: str,
                  created_date: datetime,
                  created_by: str,
-                 user_defined: bool):
+                 user_defined: bool,
+                 status: str):
         self.created_by = created_by
         self.type = service_type
         self.created_date = created_date
         self.name = name
         self.user_defined = user_defined
+        self.status = status
 
 
 class ComputeServiceInAccountResponse(ComputeServiceBaseResponse):
@@ -725,8 +743,9 @@ class ComputeServiceInAccountResponse(ComputeServiceBaseResponse):
                  created_date: datetime,
                  created_by: str,
                  user_defined: bool,
+                 status: str,
                  spaces: List[str]):
-        super().__init__(name, service_type, created_date, created_by, user_defined)
+        super().__init__(name, service_type, created_date, created_by, user_defined, status)
         self.spaces = spaces
 
 
@@ -798,9 +817,10 @@ class ComputeServiceInSpaceResponse(ComputeServiceBaseResponse):
             created_date: datetime,
             created_by: str,
             user_defined: bool,
+            status: str,
             spec: Optional[ComputeServiceSpaceSpecResponse]
     ):
-        super().__init__(name, service_type, created_date, created_by, user_defined)
+        super().__init__(name, service_type, created_date, created_by, user_defined, status)
         self.spec = spec
 
 
@@ -957,6 +977,22 @@ class AccountRepositoryResponse:
         self.errors = errors
 
 
+class AccountRepositoryDetailsBranchResponse:
+    def __init__(self, name: str):
+        self.name = name
+
+
+class AccountRepositoryDetailsResponse:
+    def __init__(self, repository_name: str,
+                 repository_full_name: str,
+                 default_branch: str,
+                 branches: [AccountRepositoryDetailsBranchResponse]):
+        self.repository_name = repository_name
+        self.repository_full_name = repository_full_name
+        self.default_branch = default_branch
+        self.branches = branches
+
+
 class BlueprintValidationResponse:
     def __init__(self,
                  name: str,
@@ -979,3 +1015,33 @@ class BlueprintValidationResponse:
         self.services = services
         self.applications = applications
         self.clouds = clouds
+
+
+class SpaceRepositoryResponse:
+    def __init__(self, repository_name: str,
+                 repository_type: str,
+                 repository_url: str,
+                 branch: str):
+        self.repository_name = repository_name
+        self.repository_type = repository_type
+        self.repository_url = repository_url
+        self.branch = branch
+
+
+class DirectAwsSshResponse:
+    def __init__(self, connection: str, pem_file_url: str):
+        self.connection = connection
+        self.pem_file_url = pem_file_url
+
+
+class DirectAzureSshResponse:
+    def __init__(self, connection: str, password: str):
+        self.connection = connection
+        self.password = password
+
+
+class DirectRdpResponse:
+    def __init__(self, rdp_file_url: str, username: str, password: str):
+        self.rdp_file_url = rdp_file_url
+        self.username = username
+        self.password = password
